==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredCredentialEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapRequiredCredentialEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> entityFieldDelegate;
    public MapRequiredCredentialEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFormLabel() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.FORM_LABEL);
    }
    @SuppressWarnings("unchecked") @Override public void setFormLabel(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.FORM_LABEL, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isSecret() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.SECRET);
    }
    @SuppressWarnings("unchecked") @Override public void setSecret(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.SECRET, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isInput() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.INPUT);
    }
    @SuppressWarnings("unchecked") @Override public void setInput(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.INPUT, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredCredentialEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapRequiredCredentialEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> entityFieldDelegate;
    public MapRequiredCredentialEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFormLabel() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.FORM_LABEL);
    }
    @SuppressWarnings("unchecked") @Override public void setFormLabel(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.FORM_LABEL, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isSecret() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.SECRET);
    }
    @SuppressWarnings("unchecked") @Override public void setSecret(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.SECRET, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isInput() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.INPUT);
    }
    @SuppressWarnings("unchecked") @Override public void setInput(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.INPUT, p0);
    }
}
